@@ -1,7 +1,7 @@
 /*
  * MainWindow.h - main window of the Veyon Configurator
  *
- * Copyright (c) 2010-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2010-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -44,7 +44,7 @@ public:
 
 	void updateView();
 
-private slots:
+private Q_SLOTS:
 	void configurationChanged();
 	void resetOrApply( QAbstractButton *btn );
 	void loadSettingsFromFile();
