@@ -1,7 +1,7 @@
 /*
  * AboutDialog.h - declaration of AboutDialog class
  *
- * Copyright (c) 2011-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2011-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -40,7 +40,7 @@ public:
 	explicit AboutDialog( QWidget *parent );
 	~AboutDialog() override;
 
-private slots:
+private Q_SLOTS:
 	void openDonationWebsite();
 
 private:
