@@ -52,11 +52,22 @@ public:
 
 	// private key auth
 	bool loadPrivateKey( const QString& privateKeyFile );
+	bool setPrivateKey( const CryptoCore::PrivateKey& privateKey );
 	const CryptoCore::PrivateKey& privateKey() const
 	{
 		return m_privateKey;
 	}
 
+	const QString& authenticationKeyName() const
+	{
+		return m_authenticationKeyName;
+	}
+
+	void setAuthenticationKeyName( const QString& authenticationKeyName )
+	{
+		m_authenticationKeyName = authenticationKeyName;
+	}
+
 	// user logon auth
 	void setLogonUsername( const QString& username )
 	{
@@ -100,6 +111,7 @@ public:
 
 private:
 	CryptoCore::PrivateKey m_privateKey;
+	QString m_authenticationKeyName;
 
 	QString m_logonUsername;
 	Password m_logonPassword;
