@@ -25,6 +25,7 @@
 #pragma once
 
 #include "ComputerControlInterface.h"
+#include "EnumHelper.h"
 #include "FeatureMessage.h"
 #include "Feature.h"
 #include "MessageContext.h"
@@ -38,7 +39,16 @@ class VeyonWorkerInterface;
 
 class VEYON_CORE_EXPORT FeatureProviderInterface
 {
+	Q_GADGET
 public:
+	enum class Operation
+	{
+		Initialize,
+		Start,
+		Stop
+	};
+	Q_ENUM(Operation)
+
 	virtual ~FeatureProviderInterface() = default;
 
 	/*!
@@ -46,6 +56,36 @@ public:
 	 */
 	virtual const FeatureList& featureList() const = 0;
 
+	virtual bool hasFeature( Feature::Uid featureUid ) const
+	{
+		for( const auto& feature : featureList() )
+		{
+			if( feature.uid() == featureUid )
+			{
+				return true;
+			}
+		}
+
+		return false;
+	}
+
+	template<class T>
+	static QString argToString( T item )
+	{
+		return EnumHelper::toCamelCaseString( item );
+	}
+
+	/*!
+	 * \brief Control feature in a generic way based on passed arguments
+	 * \param featureUid the UID of the feature to control
+	 * \param operation the operation to perform for the feature
+	 * \param arguments the arguments specifying what and how to control
+	 * \param computerControlInterfaces a list of ComputerControlInterfaces to operate on
+	 */
+	virtual bool controlFeature( Feature::Uid featureUid,
+						Operation operation, const QVariantMap& arguments,
+						const ComputerControlInterfaceList& computerControlInterfaces ) = 0;
+
 	/*!
 	 * \brief Start a feature on master side for given computer control interfaces
 	 * \param master a reference to a master instance implementing the VeyonMasterInterface
@@ -54,7 +94,12 @@ public:
 	 */
 	virtual bool startFeature( VeyonMasterInterface& master,
 							   const Feature& feature,
-							   const ComputerControlInterfaceList& computerControlInterfaces ) = 0;
+							   const ComputerControlInterfaceList& computerControlInterfaces )
+	{
+		Q_UNUSED(master)
+
+		return controlFeature( feature.uid(), Operation::Start, {}, computerControlInterfaces );
+	}
 
 	/*!
 	 * \brief Stops a feature on master side for given computer control interfaces
@@ -64,17 +109,26 @@ public:
 	 */
 	virtual bool stopFeature( VeyonMasterInterface& master,
 							  const Feature& feature,
-							  const ComputerControlInterfaceList& computerControlInterfaces ) = 0;
+							  const ComputerControlInterfaceList& computerControlInterfaces )
+	{
+		Q_UNUSED(master)
+
+		return controlFeature( feature.uid(), Operation::Stop, {}, computerControlInterfaces );
+	}
 
 	/*!
-	 * \brief Handles a received feature message inside master
-	 * \param master a reference to a master instance implementing the VeyonMasterInterface
+	 * \brief Handles a received feature message received on a certain ComputerControlInterface
 	 * \param message the message which has been received and needs to be handled
 	 * \param computerControlInterfaces the interface over which the message has been received
 	 */
-	virtual bool handleFeatureMessage( VeyonMasterInterface& master,
-									   const FeatureMessage& message,
-									   ComputerControlInterface::Pointer computerControlInterface ) = 0;
+	virtual bool handleFeatureMessage( ComputerControlInterface::Pointer computerControlInterface ,
+							  const FeatureMessage& message )
+	{
+		Q_UNUSED(computerControlInterface)
+		Q_UNUSED(message)
+
+		return false;
+	}
 
 	/*!
 	 * \brief Handles a received feature message inside server
@@ -83,17 +137,30 @@ public:
 	 */
 	virtual bool handleFeatureMessage( VeyonServerInterface& server,
 									   const MessageContext& messageContext,
-									   const FeatureMessage& message ) = 0;
+									   const FeatureMessage& message )
+	{
+		Q_UNUSED(server)
+		Q_UNUSED(messageContext)
+		Q_UNUSED(message)
+
+		return false;
+	}
 
 	/*!
 	 * \brief Handles a received feature message inside worker
 	 * \param worker a reference to a worker instance implementing the VeyonWorkerInterface
 	 * \param message the message which has been received and needs to be handled
 	 */
-	virtual bool handleFeatureMessage( VeyonWorkerInterface& worker, const FeatureMessage& message ) = 0;
+	virtual bool handleFeatureMessage( VeyonWorkerInterface& worker, const FeatureMessage& message )
+	{
+		Q_UNUSED(worker)
+		Q_UNUSED(message)
+
+		return false;
+	}
 
 protected:
-	bool sendFeatureMessage( const FeatureMessage& message,
+	void sendFeatureMessage( const FeatureMessage& message,
 							 const ComputerControlInterfaceList& computerControlInterfaces,
 							 bool wake = true )
 	{
@@ -101,8 +168,6 @@ protected:
 		{
 			controlInterface->sendFeatureMessage( message, wake );
 		}
-
-		return true;
 	}
 
 };
