@@ -28,8 +28,9 @@
 
 // clazy:excludeall=rule-of-three
 
-class VEYON_CORE_EXPORT Filesystem
+class VEYON_CORE_EXPORT Filesystem : public QObject
 {
+	Q_OBJECT
 public:
 	QString expandPath( QString path ) const;
 	QString shrinkPath( QString path ) const;
@@ -38,7 +39,12 @@ public:
 	QString privateKeyPath( const QString& name ) const;
 	QString publicKeyPath( const QString& name ) const;
 
+	QString screenshotDirectoryPath() const;
+
 	QString serverFilePath() const;
 	QString workerFilePath() const;
 
+Q_SIGNALS:
+	void screenshotDirectoryModified();
+
 };
