@@ -1,7 +1,7 @@
 /*
  * PasswordDialog.h - declaration of password dialog
  *
- * Copyright (c) 2010-2016 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2010-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -44,7 +44,7 @@ public:
 
 	void accept() override;
 
-private slots:
+private Q_SLOTS:
 	void updateOkButton();
 
 
