@@ -1,7 +1,7 @@
 /*
  * Plugin.h - generic abstraction of a plugin
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -46,4 +46,4 @@ public:
 
 };
 
-using PluginUidList = QList<Plugin::Uid>;
+using PluginUidList = QVector<Plugin::Uid>;
