@@ -45,7 +45,6 @@ class QWidget;
 
 class AuthenticationCredentials;
 class BuiltinFeatures;
-class ComputerControlInterface;
 class CryptoCore;
 class Filesystem;
 class Logger;
@@ -66,6 +65,9 @@ public:
 		Version_4_0,
 		Version_4_1,
 		Version_4_2,
+		Version_4_3,
+		Version_4_4,
+		Version_4_5,
 	};
 	Q_ENUM(ApplicationVersion)
 
@@ -143,15 +145,13 @@ public:
 		return *( instance()->m_filesystem );
 	}
 
-	static ComputerControlInterface& localComputerControlInterface()
-	{
-		return *( instance()->m_localComputerControlInterface );
-	}
-
 	static void setupApplicationParameters();
 	bool initAuthentication();
 
-	static int sessionId();
+	static int sessionId()
+	{
+		return instance()->m_sessionId;
+	}
 
 	static QString applicationName();
 	static void enforceBranding( QWidget* topLevelWidget );
@@ -164,11 +164,6 @@ public:
 	static QString stripDomain( const QString& username );
 	static QString formattedUuid( QUuid uuid );
 
-	const QString& authenticationKeyName() const
-	{
-		return m_authenticationKeyName;
-	}
-
 	static bool isAuthenticationKeyNameValid( const QString& authKeyName );
 
 	enum class AuthenticationMethod
@@ -182,6 +177,7 @@ public:
 
 private:
 	void initPlatformPlugin();
+	void initSession();
 	void initConfiguration();
 	void initLogging( const QString& appComponentName );
 	void initLocaleAndTranslation();
@@ -208,14 +204,14 @@ private:
 	UserGroupsBackendManager* m_userGroupsBackendManager;
 	NetworkObjectDirectoryManager* m_networkObjectDirectoryManager;
 
-	ComputerControlInterface* m_localComputerControlInterface;
-
 	Component m_component;
 	QString m_applicationName;
-	QString m_authenticationKeyName;
 	bool m_debugging;
 
+	int m_sessionId{0};
+
 Q_SIGNALS:
+	void initialized();
 	void applicationLoaded();
 
 };
