@@ -25,9 +25,10 @@
 #pragma once
 
 #include "Configuration/Object.h"
-#include "VeyonCore.h"
+#include "ComputerControlInterface.h"
 
 class BuiltinFeatures;
+class ComputerControlInterface;
 class QWidget;
 
 class VEYON_CORE_EXPORT VeyonMasterInterface : public QObject
@@ -45,4 +46,8 @@ public:
 	virtual Configuration::Object* userConfigurationObject() = 0;
 	virtual void reloadSubFeatures() = 0;
 
+	virtual ComputerControlInterface& localSessionControlInterface() = 0;
+
+	virtual ComputerControlInterfaceList selectedComputerControlInterfaces() const = 0;
+
 };
