@@ -63,7 +63,7 @@ ComputerControlInterface::~ComputerControlInterface()
 
 
 
-void ComputerControlInterface::start( QSize scaledScreenSize )
+void ComputerControlInterface::start( QSize scaledScreenSize, UpdateMode updateMode, AuthenticationProxy* authenticationProxy )
 {
 	// make sure we do not leak
 	stop();
@@ -77,15 +77,18 @@ void ComputerControlInterface::start( QSize scaledScreenSize )
 		m_vncConnection->setQuality( VncConnection::Quality::Thumbnail );
 		m_vncConnection->setScaledSize( m_scaledScreenSize );
 
-		enableUpdates();
+		setUpdateMode( updateMode );
 
 		m_connection = new VeyonConnection( m_vncConnection );
+		m_connection->setAuthenticationProxy( authenticationProxy );
 
 		m_vncConnection->start();
 
 		connect( m_vncConnection, &VncConnection::framebufferUpdateComplete, this, &ComputerControlInterface::resetWatchdog );
 		connect( m_vncConnection, &VncConnection::framebufferUpdateComplete, this, &ComputerControlInterface::screenUpdated );
 
+		connect( m_vncConnection, &VncConnection::framebufferSizeChanged, this, &ComputerControlInterface::screenSizeChanged );
+
 		connect( m_vncConnection, &VncConnection::stateChanged, this, &ComputerControlInterface::updateState );
 		connect( m_vncConnection, &VncConnection::stateChanged, this, &ComputerControlInterface::updateUser );
 		connect( m_vncConnection, &VncConnection::stateChanged, this, &ComputerControlInterface::updateActiveFeatures );
@@ -104,11 +107,8 @@ void ComputerControlInterface::start( QSize scaledScreenSize )
 
 void ComputerControlInterface::stop()
 {
-	if( m_connection )
-	{
-		delete m_connection;
-		m_connection = nullptr;
-	}
+	// VeyonConnection destroys itself when VncConnection is destroyed
+	m_connection = nullptr;
 
 	if( m_vncConnection )
 	{
@@ -126,6 +126,20 @@ void ComputerControlInterface::stop()
 
 
 
+bool ComputerControlInterface::hasValidFramebuffer() const
+{
+	return m_vncConnection->hasValidFramebuffer();
+}
+
+
+
+QSize ComputerControlInterface::screenSize() const
+{
+	return m_vncConnection->image().size();
+}
+
+
+
 void ComputerControlInterface::setScaledScreenSize( QSize scaledScreenSize )
 {
 	m_scaledScreenSize = scaledScreenSize;
@@ -134,8 +148,6 @@ void ComputerControlInterface::setScaledScreenSize( QSize scaledScreenSize )
 	{
 		m_vncConnection->setScaledSize( m_scaledScreenSize );
 	}
-
-	Q_EMIT screenUpdated();
 }
 
 
@@ -147,7 +159,7 @@ QImage ComputerControlInterface::scaledScreen() const
 		return m_vncConnection->scaledScreen();
 	}
 
-	return QImage();
+	return {};
 }
 
 
@@ -159,28 +171,20 @@ QImage ComputerControlInterface::screen() const
 		return m_vncConnection->image();
 	}
 
-	return QImage();
+	return {};
 }
 
 
 
-void ComputerControlInterface::setUserLoginName( const QString& userLoginName )
+void ComputerControlInterface::setUserInformation( const QString& userLoginName, const QString& userFullName, int sessionId )
 {
-	if( userLoginName != m_userLoginName )
+	if( userLoginName != m_userLoginName ||
+		userFullName != m_userFullName ||
+		sessionId != m_userSessionId )
 	{
 		m_userLoginName = userLoginName;
-
-		Q_EMIT userChanged();
-	}
-}
-
-
-
-void ComputerControlInterface::setUserFullName( const QString& userFullName )
-{
-	if( userFullName != m_userFullName )
-	{
 		m_userFullName = userFullName;
+		m_userSessionId = sessionId;
 
 		Q_EMIT userChanged();
 	}
@@ -231,30 +235,36 @@ bool ComputerControlInterface::isMessageQueueEmpty()
 
 
 
-void ComputerControlInterface::enableUpdates()
+void ComputerControlInterface::setUpdateMode( UpdateMode updateMode )
 {
-	const auto updateInterval = VeyonCore::config().computerMonitoringUpdateInterval();
+	m_updateMode = updateMode;
 
-	if( m_vncConnection )
+	const auto computerMonitoringUpdateInterval = VeyonCore::config().computerMonitoringUpdateInterval();
+
+	switch( updateMode )
 	{
-		m_vncConnection->setFramebufferUpdateInterval( updateInterval );
+	case UpdateMode::Disabled:
+		if( m_vncConnection )
+		{
+			m_vncConnection->setFramebufferUpdateInterval( UpdateIntervalDisabled );
+		}
+
+		m_userUpdateTimer.stop();
+		m_activeFeaturesUpdateTimer.start( UpdateIntervalDisabled );
+		break;
+
+	case UpdateMode::Monitoring:
+	case UpdateMode::Live:
+		if( m_vncConnection )
+		{
+			m_vncConnection->setFramebufferUpdateInterval( updateMode == UpdateMode::Monitoring ?
+															   computerMonitoringUpdateInterval : -1 );
+		}
+
+		m_userUpdateTimer.start( computerMonitoringUpdateInterval );
+		m_activeFeaturesUpdateTimer.start( computerMonitoringUpdateInterval );
+		break;
 	}
-
-	m_userUpdateTimer.start( updateInterval );
-	m_activeFeaturesUpdateTimer.start( updateInterval );
-}
-
-
-
-void ComputerControlInterface::disableUpdates()
-{
-	if( m_vncConnection )
-	{
-		m_vncConnection->setFramebufferUpdateInterval( UpdateIntervalWhenDisabled );
-	}
-
-	m_userUpdateTimer.stop();
-	m_activeFeaturesUpdateTimer.start( UpdateIntervalWhenDisabled );
 }
 
 
@@ -299,7 +309,7 @@ void ComputerControlInterface::updateState()
 		case VncConnection::State::Connecting: m_state = State::Connecting; break;
 		case VncConnection::State::Connected: m_state = State::Connected; break;
 		case VncConnection::State::HostOffline: m_state = State::HostOffline; break;
-		case VncConnection::State::ServiceUnreachable: m_state = State::ServiceUnreachable; break;
+		case VncConnection::State::ServerNotRunning: m_state = State::ServerNotRunning; break;
 		case VncConnection::State::AuthenticationFailed: m_state = State::AuthenticationFailed; break;
 		default: m_state = VncConnection::State::Disconnected; break;
 		}
@@ -323,8 +333,7 @@ void ComputerControlInterface::updateUser()
 	}
 	else
 	{
-		setUserLoginName( {} );
-		setUserFullName( {} );
+		setUserInformation( {}, {}, -1 );
 	}
 }
 
