@@ -98,7 +98,7 @@ void Property::setVariantValue( const QVariant& value ) const
 	}
 	else
 	{
-		qFatal(Q_FUNC_INFO);
+		qFatal("%s", Q_FUNC_INFO);
 	}
 }
 
