@@ -38,7 +38,7 @@
 DesktopAccessDialog::DesktopAccessDialog( QObject* parent ) :
 	QObject( parent ),
 	m_desktopAccessDialogFeature( Feature( QLatin1String( staticMetaObject.className() ),
-										   Feature::Dialog | Feature::Service | Feature::Worker | Feature::Builtin,
+										   Feature::Service | Feature::Worker | Feature::Builtin,
 										   Feature::Uid( "3dd8ec3e-7004-4936-8f2a-70699b9819be" ),
 										   Feature::Uid(),
 										   tr( "Desktop access dialog" ), {}, {} ) ),
@@ -64,8 +64,8 @@ void DesktopAccessDialog::exec( FeatureWorkerManager* featureWorkerManager, cons
 
 	featureWorkerManager->sendMessageToManagedSystemWorker(
 		FeatureMessage( m_desktopAccessDialogFeature.uid(), RequestDesktopAccess )
-			.addArgument( UserArgument, user )
-			.addArgument( HostArgument, host ) );
+			.addArgument( Argument::User, user )
+			.addArgument( Argument::Host, host ) );
 
 	connect( &m_abortTimer, &QTimer::timeout, this, [=]() { abort( featureWorkerManager ); } );
 	m_abortTimer.start( DialogTimeout );
@@ -93,7 +93,7 @@ bool DesktopAccessDialog::handleFeatureMessage( VeyonServerInterface& server,
 	if( m_desktopAccessDialogFeature.uid() == message.featureUid() &&
 		message.command() == ReportDesktopAccessChoice )
 	{
-		m_choice = QVariantHelper<Choice>::value( message.argument( ChoiceArgument ) );
+		m_choice = QVariantHelper<Choice>::value( message.argument( Argument::Choice ) );
 
 		server.featureWorkerManager().stopWorker( m_desktopAccessDialogFeature.uid() );
 
@@ -117,11 +117,11 @@ bool DesktopAccessDialog::handleFeatureMessage( VeyonWorkerInterface& worker, co
 		return false;
 	}
 
-	const auto result = requestDesktopAccess( message.argument( UserArgument ).toString(),
-											  message.argument( HostArgument ).toString() );
+	const auto result = requestDesktopAccess( message.argument( Argument::User ).toString(),
+											  message.argument( Argument::Host ).toString() );
 
 	FeatureMessage reply( m_desktopAccessDialogFeature.uid(), ReportDesktopAccessChoice );
-	reply.addArgument( ChoiceArgument, result );
+	reply.addArgument( Argument::Choice, result );
 
 	return worker.sendFeatureMessageReply( reply );
 }
