@@ -65,7 +65,7 @@ NetworkObjectDirectory* NetworkObjectDirectoryManager::configuredDirectory()
 {
 	if( m_configuredDirectory == nullptr )
 	{
-		m_configuredDirectory = createDirectory();
+		m_configuredDirectory = createDirectory( VeyonCore::config().networkObjectDirectoryPlugin(), this );
 	}
 
 	return m_configuredDirectory;
@@ -73,15 +73,13 @@ NetworkObjectDirectory* NetworkObjectDirectoryManager::configuredDirectory()
 
 
 
-NetworkObjectDirectory* NetworkObjectDirectoryManager::createDirectory()
+NetworkObjectDirectory* NetworkObjectDirectoryManager::createDirectory( Plugin::Uid uid, QObject* parent )
 {
-	const auto configuredPluginUuid = VeyonCore::config().networkObjectDirectoryPlugin();
-
 	for( auto it = m_directoryPluginInterfaces.constBegin(), end = m_directoryPluginInterfaces.constEnd(); it != end; ++it )
 	{
-		if( it.key()->uid() == configuredPluginUuid )
+		if( it.key()->uid() == uid )
 		{
-			auto directory = it.value()->createNetworkObjectDirectory( this );
+			auto directory = it.value()->createNetworkObjectDirectory( parent );
 			if( directory )
 			{
 				return directory;
@@ -93,7 +91,7 @@ NetworkObjectDirectory* NetworkObjectDirectoryManager::createDirectory()
 	{
 		if( it.key()->flags().testFlag( Plugin::ProvidesDefaultImplementation ) )
 		{
-			auto defaultDirectory = it.value()->createNetworkObjectDirectory( this );
+			auto defaultDirectory = it.value()->createNetworkObjectDirectory( parent );
 			if( defaultDirectory )
 			{
 				return defaultDirectory;
@@ -101,6 +99,6 @@ NetworkObjectDirectory* NetworkObjectDirectoryManager::createDirectory()
 		}
 	}
 
-	vCritical() << "no default plugin available! configured plugin:" << configuredPluginUuid;
+	vCritical() << "no default plugin available! requested plugin:" << uid;
 	return nullptr;
 }
