@@ -50,7 +50,7 @@ void SystemTrayIcon::setToolTip( const QString& toolTipText,
 								FeatureWorkerManager& featureWorkerManager )
 {
 	FeatureMessage featureMessage( m_systemTrayIconFeature.uid(), SetToolTipCommand );
-	featureMessage.addArgument( ToolTipTextArgument, toolTipText );
+	featureMessage.addArgument( Argument::ToolTipText, toolTipText );
 
 	featureWorkerManager.sendMessageToUnmanagedSessionWorker( featureMessage );
 }
@@ -62,8 +62,8 @@ void SystemTrayIcon::showMessage( const QString& messageTitle,
 								 FeatureWorkerManager& featureWorkerManager  )
 {
 	FeatureMessage featureMessage( m_systemTrayIconFeature.uid(), ShowMessageCommand );
-	featureMessage.addArgument( MessageTitleArgument, messageTitle );
-	featureMessage.addArgument( MessageTextArgument, messageText );
+	featureMessage.addArgument( Argument::MessageTitle, messageTitle );
+	featureMessage.addArgument( Argument::MessageText, messageText );
 
 	featureWorkerManager.sendMessageToUnmanagedSessionWorker( featureMessage );
 }
@@ -115,21 +115,21 @@ bool SystemTrayIcon::handleFeatureMessage( VeyonWorkerInterface& worker, const F
 	case SetToolTipCommand:
 		if( m_systemTrayIcon )
 		{
-			m_systemTrayIcon->setToolTip( message.argument( ToolTipTextArgument ).toString() );
+			m_systemTrayIcon->setToolTip( message.argument( Argument::ToolTipText ).toString() );
 		}
 		return true;
 
 	case ShowMessageCommand:
 		if( m_systemTrayIcon )
 		{
-			m_systemTrayIcon->showMessage( message.argument( MessageTitleArgument ).toString(),
-										   message.argument( MessageTextArgument ).toString() );
+			m_systemTrayIcon->showMessage( message.argument( Argument::MessageTitle ).toString(),
+										   message.argument( Argument::MessageText ).toString() );
 		}
 		else
 		{
 			QMessageBox::information( nullptr,
-									  message.argument( MessageTitleArgument ).toString(),
-									  message.argument( MessageTextArgument ).toString() );
+									  message.argument( Argument::MessageTitle ).toString(),
+									  message.argument( Argument::MessageText ).toString() );
 		}
 		return true;
 
