@@ -24,7 +24,7 @@
 
 #include "rfb/rfbclient.h"
 
-#include "AuthenticationCredentials.h"
+#include "AuthenticationProxy.h"
 #include "CryptoCore.h"
 #include "PlatformUserFunctions.h"
 #include "SocketDevice.h"
@@ -75,6 +75,7 @@ VeyonConnection::VeyonConnection( VncConnection* vncConnection ):
 	}
 
 	connect( m_vncConnection, &VncConnection::connectionPrepared, this, &VeyonConnection::registerConnection, Qt::DirectConnection );
+	connect( m_vncConnection, &VncConnection::destroyed, this, &VeyonConnection::deleteLater );
 }
 
 
@@ -82,6 +83,8 @@ VeyonConnection::VeyonConnection( VncConnection* vncConnection ):
 VeyonConnection::~VeyonConnection()
 {
 	unregisterConnection();
+
+	delete m_authenticationProxy;
 }
 
 
@@ -179,6 +182,13 @@ int8_t VeyonConnection::handleSecTypeVeyon( rfbClient* client, uint32_t authSche
 		authTypes.append( QVariantHelper<RfbVeyonAuth::Type>::value( message.read() ) );
 	}
 
+	auto proxy = connection->m_authenticationProxy;
+
+	if( proxy )
+	{
+		proxy->setAuthenticationTypes( authTypes );
+	}
+
 	vDebug() << QThread::currentThreadId() << "received authentication types:" << authTypes;
 
 	RfbVeyonAuth::Type chosenAuthType = RfbVeyonAuth::Token;
@@ -199,6 +209,16 @@ int8_t VeyonConnection::handleSecTypeVeyon( rfbClient* client, uint32_t authSche
 		}
 	}
 
+	if( proxy )
+	{
+		chosenAuthType = proxy->initCredentials();
+	}
+
+	if( chosenAuthType == RfbVeyonAuth::None )
+	{
+		return false;
+	}
+
 	vDebug() << QThread::currentThreadId() << "chose authentication type:" << authTypes;
 
 	VariantArrayMessage authReplyMessage( &socketDevice );
@@ -206,9 +226,9 @@ int8_t VeyonConnection::handleSecTypeVeyon( rfbClient* client, uint32_t authSche
 	authReplyMessage.write( chosenAuthType );
 
 	// send username which is used when displaying an access confirm dialog
-	if( VeyonCore::authenticationCredentials().hasCredentials( AuthenticationCredentials::Type::UserLogon ) )
+	if( connection->authenticationCredentials().hasCredentials( AuthenticationCredentials::Type::UserLogon ) )
 	{
-		authReplyMessage.write( VeyonCore::authenticationCredentials().logonUsername() );
+		authReplyMessage.write( connection->authenticationCredentials().logonUsername() );
 	}
 	else
 	{
@@ -223,7 +243,7 @@ int8_t VeyonConnection::handleSecTypeVeyon( rfbClient* client, uint32_t authSche
 	switch( chosenAuthType )
 	{
 	case RfbVeyonAuth::KeyFile:
-		if( VeyonCore::authenticationCredentials().hasCredentials( AuthenticationCredentials::Type::PrivateKey ) )
+		if( connection->authenticationCredentials().hasCredentials( AuthenticationCredentials::Type::PrivateKey ) )
 		{
 			VariantArrayMessage challengeReceiveMessage( &socketDevice );
 			challengeReceiveMessage.receive();
@@ -236,7 +256,7 @@ int8_t VeyonConnection::handleSecTypeVeyon( rfbClient* client, uint32_t authSche
 			}
 
 			// create local copy of private key so we can modify it within our own thread
-			auto key = VeyonCore::authenticationCredentials().privateKey();
+			auto key = connection->authenticationCredentials().privateKey();
 			if( key.isNull() || key.canSign() == false )
 			{
 				vCritical() << QThread::currentThreadId() << "invalid private key!";
@@ -246,7 +266,7 @@ int8_t VeyonConnection::handleSecTypeVeyon( rfbClient* client, uint32_t authSche
 			const auto signature = key.signMessage( challenge, CryptoCore::DefaultSignatureAlgorithm );
 
 			VariantArrayMessage challengeResponseMessage( &socketDevice );
-			challengeResponseMessage.write( VeyonCore::instance()->authenticationKeyName() );
+			challengeResponseMessage.write( connection->authenticationCredentials().authenticationKeyName() );
 			challengeResponseMessage.write( signature );
 			challengeResponseMessage.send();
 		}
@@ -265,7 +285,7 @@ int8_t VeyonConnection::handleSecTypeVeyon( rfbClient* client, uint32_t authSche
 			return false;
 		}
 
-		CryptoCore::SecureArray plainTextPassword( VeyonCore::authenticationCredentials().logonPassword() );
+		CryptoCore::SecureArray plainTextPassword( connection->authenticationCredentials().logonPassword() );
 		CryptoCore::SecureArray encryptedPassword = publicKey.encrypt( plainTextPassword, CryptoCore::DefaultEncryptionAlgorithm );
 		if( encryptedPassword.isEmpty() )
 		{
@@ -282,7 +302,7 @@ int8_t VeyonConnection::handleSecTypeVeyon( rfbClient* client, uint32_t authSche
 	case RfbVeyonAuth::Token:
 	{
 		VariantArrayMessage tokenAuthMessage( &socketDevice );
-		tokenAuthMessage.write( VeyonCore::authenticationCredentials().token().toByteArray() );
+		tokenAuthMessage.write( connection->authenticationCredentials().token().toByteArray() );
 		tokenAuthMessage.send();
 		break;
 	}
@@ -307,3 +327,15 @@ void VeyonConnection::hookPrepareAuthentication( rfbClient* client )
 		connection->setServerReachable();
 	}
 }
+
+
+
+AuthenticationCredentials VeyonConnection::authenticationCredentials() const
+{
+	if( m_authenticationProxy )
+	{
+		return m_authenticationProxy->credentials();
+	}
+
+	return VeyonCore::authenticationCredentials();
+}
