@@ -29,7 +29,6 @@
 #include <QApplication>
 #include <QDir>
 #include <QGroupBox>
-#include <QHostAddress>
 #include <QLabel>
 #include <QProcessEnvironment>
 #include <QSysInfo>
@@ -43,7 +42,6 @@
 #include "PasswordDialog.h"
 #include "PlatformPluginManager.h"
 #include "PlatformCoreFunctions.h"
-#include "PlatformServiceCore.h"
 #include "PlatformSessionFunctions.h"
 #include "PluginManager.h"
 #include "TranslationLoader.h"
@@ -68,10 +66,8 @@ VeyonCore::VeyonCore( QCoreApplication* application, Component component, const
 	m_builtinFeatures( nullptr ),
 	m_userGroupsBackendManager( nullptr ),
 	m_networkObjectDirectoryManager( nullptr ),
-	m_localComputerControlInterface( nullptr ),
 	m_component( component ),
 	m_applicationName( QStringLiteral( "Veyon" ) ),
-	m_authenticationKeyName(),
 	m_debugging( false )
 {
 	Q_ASSERT( application != nullptr );
@@ -84,6 +80,8 @@ VeyonCore::VeyonCore( QCoreApplication* application, Component component, const
 
 	initConfiguration();
 
+	initSession();
+
 	initLogging( appComponentName );
 
 	initLocaleAndTranslation();
@@ -96,9 +94,9 @@ VeyonCore::VeyonCore( QCoreApplication* application, Component component, const
 
 	initManagers();
 
-	initLocalComputerControlInterface();
-
 	initSystemInfo();
+
+	Q_EMIT initialized();
 }
 
 
@@ -223,24 +221,6 @@ bool VeyonCore::initAuthentication()
 
 
 
-int VeyonCore::sessionId()
-{
-	if( config().multiSessionModeEnabled() )
-	{
-		const auto systemEnv = QProcessEnvironment::systemEnvironment();
-		if( systemEnv.contains( sessionIdEnvironmentVariable() ) )
-		{
-			return systemEnv.value( sessionIdEnvironmentVariable() ).toInt();
-		}
-
-		return platform().sessionFunctions().currentSessionId();
-	}
-
-	return PlatformSessionFunctions::DefaultSession;
-}
-
-
-
 QString VeyonCore::applicationName()
 {
 	return instance()->m_applicationName;
@@ -525,6 +505,31 @@ void VeyonCore::initPlatformPlugin()
 
 
 
+void VeyonCore::initSession()
+{
+	if( config().multiSessionModeEnabled() )
+	{
+		const auto systemEnv = QProcessEnvironment::systemEnvironment();
+		if( systemEnv.contains( sessionIdEnvironmentVariable() ) )
+		{
+			m_sessionId = systemEnv.value( sessionIdEnvironmentVariable() ).toInt();
+		}
+		else
+		{
+			const auto sessionId = platform().sessionFunctions().currentSessionId();
+			if( sessionId != PlatformSessionFunctions::InvalidSessionId )
+			{
+				m_sessionId = sessionId;
+			}
+		}
+	}
+	else
+	{
+		m_sessionId = PlatformSessionFunctions::DefaultSessionId;
+	}
+}
+
+
 void VeyonCore::initConfiguration()
 {
 	m_config = new VeyonConfiguration();
@@ -547,7 +552,7 @@ void VeyonCore::initLogging( const QString& appComponentName )
 {
 	const auto currentSessionId = sessionId();
 
-	if( currentSessionId != PlatformSessionFunctions::DefaultSession )
+	if( currentSessionId != PlatformSessionFunctions::DefaultSessionId )
 	{
 		m_logger = new Logger( QStringLiteral("%1-%2").arg( appComponentName ).arg( currentSessionId ) );
 	}
@@ -621,17 +626,6 @@ void VeyonCore::initManagers()
 
 
 
-void VeyonCore::initLocalComputerControlInterface()
-{
-	const Computer localComputer( NetworkObject::Uid::createUuid(),
-								  QStringLiteral("localhost"),
-								  QStringLiteral("%1:%2").arg( QHostAddress( QHostAddress::LocalHost ).toString() ).arg( config().primaryServicePort() + sessionId() ) );
-
-	m_localComputerControlInterface = new ComputerControlInterface( localComputer, this );
-}
-
-
-
 bool VeyonCore::initLogonAuthentication()
 {
 	if( qobject_cast<QApplication *>( QCoreApplication::instance() ) )
@@ -661,7 +655,7 @@ bool VeyonCore::initKeyFileAuthentication()
 		if( isAuthenticationKeyNameValid( authKeyName ) &&
 				m_authenticationCredentials->loadPrivateKey( VeyonCore::filesystem().privateKeyPath( authKeyName ) ) )
 		{
-			m_authenticationKeyName = authKeyName;
+			m_authenticationCredentials->setAuthenticationKeyName( authKeyName );
 		}
 	}
 	else
@@ -674,7 +668,7 @@ bool VeyonCore::initKeyFileAuthentication()
 		{
 			if( m_authenticationCredentials->loadPrivateKey( VeyonCore::filesystem().privateKeyPath( privateKeyDir ) ) )
 			{
-				m_authenticationKeyName = privateKeyDir;
+				m_authenticationCredentials->setAuthenticationKeyName( privateKeyDir );
 				return true;
 			}
 		}
