@@ -171,7 +171,7 @@ VncConnection::VncConnection( QObject* parent ) :
 	m_quality( Quality::Default ),
 	m_host(),
 	m_port( -1 ),
-	m_defaultPort( VeyonCore::config().primaryServicePort() ),
+	m_defaultPort( VeyonCore::config().veyonServerPort() ),
 	m_globalMutex(),
 	m_eventQueueMutex(),
 	m_updateIntervalSleeper(),
@@ -357,7 +357,7 @@ void VncConnection::setFramebufferUpdateInterval( int interval )
 
 void VncConnection::rescaleScreen()
 {
-	if( hasValidFrameBuffer() == false || m_scaledSize.isNull() )
+	if( hasValidFramebuffer() == false || m_scaledSize.isNull() )
 	{
 		m_scaledScreen = {};
 		return;
@@ -495,7 +495,7 @@ void VncConnection::establishConnection()
 				}
 				else
 				{
-					setState( State::ServiceUnreachable );
+					setState( State::ServerNotRunning );
 				}
 			}
 			else if( m_framebufferState == FramebufferState::Invalid )
