@@ -26,13 +26,11 @@
 
 #include <QMainWindow>
 
-#include "Feature.h"
+#include "ComputerControlInterface.h"
 
 class QButtonGroup;
 class QToolButton;
 
-class ComputerSelectPanel;
-class ScreenshotManagementPanel;
 class VeyonMaster;
 
 namespace Ui {
@@ -57,8 +55,11 @@ public:
 
 	void reloadSubFeatures();
 
+	ComputerControlInterfaceList selectedComputerControlInterfaces() const;
+
 protected:
 	void closeEvent( QCloseEvent* event ) override;
+	bool eventFilter( QObject* object, QEvent* event ) override;
 	void keyPressEvent( QKeyEvent *e ) override;
 
 
@@ -71,6 +72,11 @@ private:
 		return static_cast<int>( qHash( feature.uid() ) );
 	}
 
+	static constexpr const char* originalSizePropertyName()
+	{
+		return "originalSize";
+	}
+
 	void addFeaturesToToolBar();
 	void addSubFeaturesToToolButton( QToolButton* button, const Feature& parentFeature );
 
@@ -82,7 +88,4 @@ private:
 
 	QButtonGroup* m_modeGroup;
 
-	ComputerSelectPanel* m_computerSelectPanel;
-	ScreenshotManagementPanel* m_screenshotManagementPanel;
-
 } ;
