@@ -1,7 +1,7 @@
 /*
  * NetworkObjectTreeModel.cpp - data model returning hierarchically grouped network objects
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -232,7 +232,7 @@ void NetworkObjectTreeModel::updateObject( const NetworkObject& parent, int row
 {
 	const auto index = createIndex( row, 0, parent.modelId() );
 
-	emit dataChanged( index, index );
+	Q_EMIT dataChanged( index, index );
 }
 
 
