@@ -1,7 +1,7 @@
 /*
  * AuthKeysConfigurationPage.cpp - implementation of the authentication configuration page
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -202,7 +202,7 @@ void AuthKeysConfigurationPage::exportKey()
 		if( outputFile.isEmpty() == false )
 		{
 			AuthKeysManager authKeysManager;
-			const auto success = authKeysManager.exportKey( name, type, outputFile );
+			const auto success = authKeysManager.exportKey( name, type, outputFile, true );
 
 			showResultMessage( success, title, authKeysManager.resultMessage() );
 		}
