@@ -1,7 +1,7 @@
 /*
  * BuiltinDirectoryConfigurationPage.h - header for the BuiltinDirectoryConfigurationPage class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -44,7 +44,7 @@ public:
 	void connectWidgetsToProperties() override;
 	void applyConfiguration() override;
 
-private slots:
+private Q_SLOTS:
 	void addLocation();
 	void updateLocation();
 	void removeLocation();
