@@ -1,7 +1,7 @@
 /*
  * BuiltinDirectoryPlugin.cpp - implementation of BuiltinDirectoryPlugin class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -30,6 +30,7 @@
 #include "CommandLineIO.h"
 #include "ConfigurationManager.h"
 #include "ObjectManager.h"
+#include "PlatformFilesystemFunctions.h"
 #include "VeyonConfiguration.h"
 
 
@@ -404,7 +405,10 @@ CommandLinePluginInterface::RunResult BuiltinDirectoryPlugin::handle_export( con
 	const auto& outputFileName = arguments.first();
 	QFile outputFile( outputFileName );
 
-	if( outputFile.open( QFile::WriteOnly | QFile::Truncate | QFile::Text ) == false )
+	if( VeyonCore::platform().filesystemFunctions().openFileSafely(
+			&outputFile,
+			QFile::WriteOnly | QFile::Truncate | QFile::Text,
+			QFile::ReadOwner | QFile::WriteOwner ) == false )
 	{
 		error( tr( "Can't open file \"%1\" for writing!" ).arg( outputFileName ) );
 		return Failed;
@@ -592,18 +596,18 @@ bool BuiltinDirectoryPlugin::importFile( QFile& inputFile,
 		else if( parentLocation.isValid() == false )
 		{
 			parentLocation = NetworkObject( NetworkObject::Type::Location, it.key() );
-			objectManager.add( parentLocation );
+			objectManager.update( parentLocation, true );
 			parentLocationUid = parentLocation.uid();
 		}
 
 		for( const NetworkObject& networkObject : qAsConst(it.value()) )
 		{
-			objectManager.add( NetworkObject( networkObject.type(),
-											  networkObject.name(),
-											  networkObject.hostAddress(),
-											  networkObject.macAddress(),
-											  {}, NetworkObject::Uid(),
-											  parentLocationUid ) );
+			objectManager.update( NetworkObject( networkObject.type(),
+												 networkObject.name(),
+												 networkObject.hostAddress(),
+												 networkObject.macAddress(),
+												 {}, NetworkObject::Uid(),
+												 parentLocationUid ), true );
 		}
 	}
 
@@ -653,7 +657,7 @@ bool BuiltinDirectoryPlugin::exportFile( QFile& outputFile, const QString& forma
 	// append empty string to generate final newline at end of file
 	lines += QString();
 
-	outputFile.write( lines.join( QStringLiteral("\r\n") ).toUtf8() );
+	outputFile.write( lines.join( QStringLiteral("\n") ).toUtf8() );
 
 	return true;
 }
