@@ -1,7 +1,7 @@
 /*
  * ConfigCommandLinePlugin.h - declaration of ConfigCommandLinePlugin class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -79,7 +79,7 @@ public:
 	QStringList commands() const override;
 	QString commandHelp( const QString& command ) const override;
 
-public slots:
+public Q_SLOTS:
 	CommandLinePluginInterface::RunResult handle_clear( const QStringList& arguments );
 	CommandLinePluginInterface::RunResult handle_list( const QStringList& arguments );
 	CommandLinePluginInterface::RunResult handle_import( const QStringList& arguments );
@@ -90,8 +90,14 @@ public slots:
 	CommandLinePluginInterface::RunResult handle_upgrade( const QStringList& arguments );
 
 private:
-	void listConfiguration( const VeyonConfiguration::DataMap &map,
-							const QString &parentKey );
+	enum class ListMode {
+		Values,
+		Defaults,
+		Types
+	};
+
+	void listConfiguration( ListMode listMode ) const;
+
 	CommandLinePluginInterface::RunResult applyConfiguration();
 
 	static QString printableConfigurationValue( const QVariant& value );
