@@ -31,10 +31,10 @@
 #include "VeyonConfiguration.h"
 #include "LockWidget.h"
 #include "PlatformCoreFunctions.h"
-#include "VncView.h"
+#include "VncViewWidget.h"
 
 
-DemoClient::DemoClient( const QString& host, int port, bool fullscreen, QObject* parent ) :
+DemoClient::DemoClient( const QString& host, int port, bool fullscreen, const QRect& viewport, QObject* parent ) :
 	QObject( parent ),
 	m_toplevel( nullptr )
 {
@@ -57,7 +57,7 @@ DemoClient::DemoClient( const QString& host, int port, bool fullscreen, QObject*
 		m_toplevel->resize( QApplication::desktop()->availableGeometry( m_toplevel ).size() - QSize( 10, 30 ) );
 	}
 
-	m_vncView = new VncView( host, port, m_toplevel, VncView::DemoMode );
+	m_vncView = new VncViewWidget( host, port, m_toplevel, VncView::DemoMode, viewport );
 
 	auto toplevelLayout = new QVBoxLayout;
 	toplevelLayout->setContentsMargins( 0, 0, 0, 0 );
@@ -67,7 +67,7 @@ DemoClient::DemoClient( const QString& host, int port, bool fullscreen, QObject*
 	m_toplevel->setLayout( toplevelLayout );
 
 	connect( m_toplevel, &QObject::destroyed, this, &DemoClient::viewDestroyed );
-	connect( m_vncView, &VncView::sizeHintChanged, this, &DemoClient::resizeToplevelWidget );
+	connect( m_vncView, &VncViewWidget::sizeHintChanged, this, &DemoClient::resizeToplevelWidget );
 
 	m_toplevel->move( 0, 0 );
 	if( fullscreen )
