@@ -1,7 +1,7 @@
 /*
- * DemoClient.h - client for demo-server
+ * DemoClient.h - client for demo server
  *
- * Copyright (c) 2006-2013 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -26,13 +26,13 @@
 
 #include <QObject>
 
-class VncView;
+class VncViewWidget;
 
 class DemoClient : public QObject
 {
 	Q_OBJECT
 public:
-	DemoClient( const QString& host, int port, bool fullscreen, QObject* parent = nullptr );
+	DemoClient( const QString& host, int port, bool fullscreen, const QRect& viewport, QObject* parent = nullptr );
 	~DemoClient() override;
 
 private:
@@ -40,6 +40,6 @@ private:
 	void resizeToplevelWidget();
 
 	QWidget* m_toplevel;
-	VncView* m_vncView;
+	VncViewWidget* m_vncView;
 
 } ;
