@@ -24,10 +24,14 @@
 
 #pragma once
 
+#include <QGuiApplication>
+
 #include "ConfigurationPagePluginInterface.h"
 #include "DemoConfiguration.h"
 #include "FeatureProviderInterface.h"
 
+class QScreen;
+
 class DemoServer;
 class DemoClient;
 
@@ -39,6 +43,20 @@ class DemoFeaturePlugin : public QObject, FeatureProviderInterface, PluginInterf
 public:
 	using Token = CryptoCore::PlaintextPassword;
 
+	enum class Argument {
+		DemoAccessToken,
+		VncServerPort,
+		VncServerPassword,
+		DemoServerHost,
+		DemoServerPort,
+		Viewport,
+		ViewportX,
+		ViewportY,
+		ViewportWidth,
+		ViewportHeight
+	};
+	Q_ENUM(Argument)
+
 	explicit DemoFeaturePlugin( QObject* parent = nullptr );
 	~DemoFeaturePlugin() override = default;
 
@@ -77,15 +95,15 @@ public:
 		return m_features;
 	}
 
+	bool controlFeature( Feature::Uid featureUid, Operation operation, const QVariantMap& arguments,
+						const ComputerControlInterfaceList& computerControlInterfaces ) override;
+
 	bool startFeature( VeyonMasterInterface& master, const Feature& feature,
 					   const ComputerControlInterfaceList& computerControlInterfaces ) override;
 
 	bool stopFeature( VeyonMasterInterface& master, const Feature& feature,
 					  const ComputerControlInterfaceList& computerControlInterfaces ) override;
 
-	bool handleFeatureMessage( VeyonMasterInterface& master, const FeatureMessage& message,
-							   ComputerControlInterface::Pointer computerControlInterface ) override;
-
 	bool handleFeatureMessage( VeyonServerInterface& server,
 							   const MessageContext& messageContext,
 							   const FeatureMessage& message ) override;
@@ -95,6 +113,20 @@ public:
 	ConfigurationPage* createConfigurationPage() override;
 
 private:
+	static constexpr auto ScreenSelectionNone = 0;
+
+	void addScreen( QScreen* screen );
+	void removeScreen( QScreen* screen );
+
+	void updateFeatures();
+
+	QRect viewportFromScreenSelection() const;
+
+	bool controlDemoServer( Operation operation, const QVariantMap& arguments,
+						   const ComputerControlInterfaceList& computerControlInterfaces );
+	bool controlDemoClient( Feature::Uid featureUid, Operation operation, const QVariantMap& arguments,
+						   const ComputerControlInterfaceList& computerControlInterfaces );
+
 	enum Commands {
 		StartDemoServer,
 		StopDemoServer,
@@ -102,18 +134,20 @@ private:
 		StopDemoClient
 	};
 
-	enum Arguments {
-		DemoAccessToken,
-		VncServerPort,
-		VncServerPassword,
-		DemoServerHost,
-		DemoServerPort
-	};
-
-	const Feature m_fullscreenDemoFeature;
-	const Feature m_windowDemoFeature;
+	const Feature m_demoFeature;
+	const Feature m_demoClientFullScreenFeature;
+	const Feature m_demoClientWindowFeature;
+	const Feature m_shareOwnScreenFullScreenFeature;
+	const Feature m_shareOwnScreenWindowFeature;
+	const Feature m_shareUserScreenFullScreenFeature;
+	const Feature m_shareUserScreenWindowFeature;
 	const Feature m_demoServerFeature;
-	const FeatureList m_features;
+	const FeatureList m_staticFeatures{};
+	FeatureList m_features{};
+
+	FeatureList m_screenSelectionFeatures{};
+	int m_screenSelection{ScreenSelectionNone};
+	QList<QScreen *> m_screens{QGuiApplication::screens()};
 
 	Token m_demoAccessToken;
 	QStringList m_demoClientHosts;
