@@ -25,7 +25,6 @@
 
 #include "rfb/rfbproto.h"
 
-#include <QTcpServer>
 #include <QTcpSocket>
 
 #include "DemoConfiguration.h"
@@ -37,13 +36,12 @@
 
 DemoServer::DemoServer( int vncServerPort, const Password& vncServerPassword, const Password& demoAccessToken,
 						const DemoConfiguration& configuration, int demoServerPort, QObject *parent ) :
-	QObject( parent ),
+	QTcpServer( parent ),
 	m_configuration( configuration ),
 	m_memoryLimit( m_configuration.memoryLimit() * 1024*1024 ),
 	m_keyFrameInterval( m_configuration.keyFrameInterval() * 1000 ),
 	m_vncServerPort( vncServerPort ),
 	m_demoAccessToken( demoAccessToken ),
-	m_tcpServer( new QTcpServer( this ) ),
 	m_vncServerSocket( new QTcpSocket( this ) ),
 	m_vncClientProtocol( new VncClientProtocol( m_vncServerSocket, vncServerPassword ) ),
 	m_framebufferUpdateTimer( this ),
@@ -51,14 +49,12 @@ DemoServer::DemoServer( int vncServerPort, const Password& vncServerPassword, co
 	m_requestFullFramebufferUpdate( false ),
 	m_keyFrame( 0 )
 {
-	connect( m_tcpServer, &QTcpServer::newConnection, this, &DemoServer::acceptPendingConnections );
-
 	connect( m_vncServerSocket, &QTcpSocket::readyRead, this, &DemoServer::readFromVncServer );
 	connect( m_vncServerSocket, &QTcpSocket::disconnected, this, &DemoServer::reconnectToVncServer );
 
 	connect( &m_framebufferUpdateTimer, &QTimer::timeout, this, &DemoServer::requestFramebufferUpdate );
 
-	if( m_tcpServer->listen( QHostAddress::Any, demoServerPort ) == false )
+	if( listen( QHostAddress::Any, demoServerPort ) == false )
 	{
 		vCritical() << "could not listen to demo server port";
 		return;
@@ -75,25 +71,24 @@ DemoServer::~DemoServer()
 {
 	vDebug() << "disconnecting signals";
 	m_vncServerSocket->disconnect( this );
-	m_tcpServer->disconnect( this );
 
 	vDebug() << "deleting connections";
 
 	QList<DemoServerConnection *> l;
 	while( !( l = findChildren<DemoServerConnection *>() ).isEmpty() )
 	{
-		delete l.front();
+		l.front()->quit();
+		l.front()->wait( ConnectionThreadWaitTime );
+		l.front()->terminate();
+		l.front()->deleteLater();
 	}
 
-	vDebug() << "deleting server socket";
-	delete m_vncServerSocket;
-
-	vDebug() << "deleting TCP server";
-	delete m_tcpServer;
-
 	vDebug() << "deleting VNC client protocol";
 	delete m_vncClientProtocol;
 
+	vDebug() << "deleting server socket";
+	delete m_vncServerSocket;
+
 	vDebug() << "finished";
 }
 
@@ -122,16 +117,25 @@ void DemoServer::lockDataForRead()
 
 
 
-void DemoServer::acceptPendingConnections()
+void DemoServer::incomingConnection( qintptr socketDescriptor )
 {
-	if( m_vncClientProtocol->state() != VncClientProtocol::Running )
+	m_pendingConnections.append( socketDescriptor );
+
+	if( m_vncClientProtocol->state() != VncClientProtocol::State::Running )
 	{
 		return;
 	}
 
-	while( m_tcpServer->hasPendingConnections() )
+	acceptPendingConnections();
+}
+
+
+
+void DemoServer::acceptPendingConnections()
+{
+	while( m_pendingConnections.isEmpty() == false )
 	{
-		new DemoServerConnection( m_demoAccessToken, m_tcpServer->nextPendingConnection(), this );
+		new DemoServerConnection( this, m_demoAccessToken, m_pendingConnections.takeFirst() );
 	}
 }
 
