@@ -33,7 +33,7 @@ class DemoServer;
 // the demo server creates an instance of this class for each client connection,
 // i.e. each client is connected to a different server thread for best
 // performance
-class DemoServerConnection : public QObject
+class DemoServerConnection : public QThread
 {
 	Q_OBJECT
 public:
@@ -43,22 +43,25 @@ public:
 		ProtocolRetryTime = 250,
 	};
 
-	DemoServerConnection( const Password& demoAccessToken, QTcpSocket* socket, DemoServer* demoServer );
-	~DemoServerConnection() override;
+	DemoServerConnection( DemoServer* demoServer, const Password& demoAccessToken, quintptr socketDescriptor );
+	~DemoServerConnection() = default;
+
+private:
+	void run() override;
 
-public Q_SLOTS:
 	void processClient();
 	void sendFramebufferUpdate();
 
-private:
 	bool receiveClientMessage();
 
+	const Password m_demoAccessToken;
 	DemoServer* m_demoServer;
 
-	QTcpSocket* m_socket;
+	quintptr m_socketDescriptor;
+	QTcpSocket* m_socket{nullptr};
 
 	VncServerClient m_vncServerClient;
-	DemoServerProtocol m_serverProtocol;
+	DemoServerProtocol* m_serverProtocol{nullptr};
 
 	const QMap<int, int> m_rfbClientToServerMessageSizes;
 
