@@ -1,7 +1,7 @@
 /*
  * DesktopServicesConfigurationPage.h - header for the DesktopServicesConfigurationPage class
  *
- * Copyright (c) 2018-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2018-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -45,7 +45,7 @@ public:
 	void connectWidgetsToProperties() override;
 	void applyConfiguration() override;
 
-private slots:
+private Q_SLOTS:
 	void addProgram();
 	void updateProgram();
 	void removeProgram();
