@@ -26,16 +26,31 @@
 
 #include <QFile>
 
+#include "ConfigurationPagePluginInterface.h"
 #include "FeatureProviderInterface.h"
+#include "FileTransferConfiguration.h"
 
 class FileTransferController;
 
-class FileTransferPlugin : public QObject, FeatureProviderInterface, PluginInterface
+class FileTransferPlugin : public QObject, FeatureProviderInterface, PluginInterface, ConfigurationPagePluginInterface
 {
 	Q_OBJECT
 	Q_PLUGIN_METADATA(IID "io.veyon.Veyon.Plugins.FileTransfer")
-	Q_INTERFACES(PluginInterface FeatureProviderInterface)
+	Q_INTERFACES(PluginInterface
+					  FeatureProviderInterface
+						  ConfigurationPagePluginInterface)
 public:
+	enum class Argument
+	{
+		TransferId,
+		Filename,
+		DataChunk,
+		OpenFileInApplication,
+		OverwriteExistingFile,
+		Files
+	};
+	Q_ENUM(Argument)
+
 	explicit FileTransferPlugin( QObject* parent = nullptr );
 	~FileTransferPlugin() override;
 
@@ -74,15 +89,12 @@ public:
 		return m_features;
 	}
 
+	bool controlFeature( Feature::Uid featureUid, Operation operation, const QVariantMap& arguments,
+						const ComputerControlInterfaceList& computerControlInterfaces ) override;
+
 	bool startFeature( VeyonMasterInterface& master, const Feature& feature,
 					   const ComputerControlInterfaceList& computerControlInterfaces ) override;
 
-	bool stopFeature( VeyonMasterInterface& master, const Feature& feature,
-					  const ComputerControlInterfaceList& computerControlInterfaces ) override;
-
-	bool handleFeatureMessage( VeyonMasterInterface& master, const FeatureMessage& message,
-							   ComputerControlInterface::Pointer computerControlInterface ) override;
-
 	bool handleFeatureMessage( VeyonServerInterface& server,
 							   const MessageContext& messageContext,
 							   const FeatureMessage& message ) override;
@@ -97,7 +109,11 @@ public:
 							bool openFileInApplication, const ComputerControlInterfaceList& interfaces );
 	void sendOpenTransferFolderMessage( const ComputerControlInterfaceList& interfaces );
 
+	ConfigurationPage* createConfigurationPage() override;
+
 private:
+	QString destinationDirectory() const;
+
 	enum Commands
 	{
 		FileTransferStartCommand,
@@ -108,22 +124,17 @@ private:
 		CommandCount
 	};
 
-	enum Arguments
-	{
-		TransferId,
-		Filename,
-		DataChunk,
-		OpenFileInApplication,
-		OverwriteExistingFile,
-		ArgumentsCount
-	};
-
 	const Feature m_fileTransferFeature;
 	const FeatureList m_features;
 
-	FileTransferController* m_fileTransferController;
+	FileTransferConfiguration m_configuration;
 
-	QFile m_currentFile;
-	QUuid m_currentTransferId;
+	QString m_lastFileTransferSourceDirectory;
+
+	FileTransferController* m_fileTransferController{nullptr};
+
+	QFile m_currentFile{};
+	QString m_currentFileName{};
+	QUuid m_currentTransferId{};
 
 };
