@@ -1,7 +1,7 @@
 /*
  * LdapClient.h - class implementing an LDAP client
  *
- * Copyright (c) 2016-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2016-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -27,6 +27,8 @@
 #include <QObject>
 #include <QUrl>
 
+#include "LdapCommon.h"
+
 namespace KLDAP {
 class LdapConnection;
 class LdapOperation;
@@ -35,7 +37,7 @@ class LdapServer;
 
 class LdapConfiguration;
 
-class LdapClient : public QObject
+class LDAP_COMMON_EXPORT LdapClient : public QObject
 {
 	Q_OBJECT
 public:
@@ -122,6 +124,7 @@ public:
 private:
 	static constexpr int LdapQueryTimeout = 3000;
 	static constexpr int LdapConnectionTimeout = 60*1000;
+	static constexpr auto LdapLibraryDebugAny = -1;
 
 	bool reconnect();
 	bool connectAndBind( const QUrl& url );
