@@ -22,6 +22,7 @@
  *
  */
 
+#include <QFileInfo>
 #include <QDBusPendingCall>
 #include <QProcess>
 #include <QProcessEnvironment>
@@ -63,8 +64,20 @@ void LinuxCoreFunctions::writeToNativeLoggingSystem( const QString& message, Log
 
 void LinuxCoreFunctions::reboot()
 {
+	systemdLoginManager()->asyncCall( QStringLiteral("Reboot"), false );
+	consoleKitManager()->asyncCall( QStringLiteral("Restart") );
+
 	if( isRunningAsAdmin() )
 	{
+		for( const auto& file : { QStringLiteral("/sbin/reboot"), QStringLiteral("/usr/sbin/reboot") } )
+		{
+			if( QFileInfo::exists( file ) )
+			{
+				QProcess::startDetached( file, {} );
+				return;
+			}
+		}
+
 		QProcess::startDetached( QStringLiteral("reboot"), {} );
 	}
 	else
@@ -76,8 +89,6 @@ void LinuxCoreFunctions::reboot()
 		gnomeSessionManager()->asyncCall( QStringLiteral("RequestReboot") );
 		mateSessionManager()->asyncCall( QStringLiteral("RequestReboot") );
 		xfcePowerManager()->asyncCall( QStringLiteral("Reboot") );
-		systemdLoginManager()->asyncCall( QStringLiteral("Reboot") );
-		consoleKitManager()->asyncCall( QStringLiteral("Restart") );
 	}
 }
 
@@ -87,8 +98,20 @@ void LinuxCoreFunctions::powerDown( bool installUpdates )
 {
 	Q_UNUSED(installUpdates)
 
+	systemdLoginManager()->asyncCall( QStringLiteral("PowerOff"), false );
+	consoleKitManager()->asyncCall( QStringLiteral("Stop") );
+
 	if( isRunningAsAdmin() )
 	{
+		for( const auto& file : { QStringLiteral("/sbin/poweroff"), QStringLiteral("/usr/sbin/poweroff") } )
+		{
+			if( QFileInfo::exists( file ) )
+			{
+				QProcess::startDetached( file, {} );
+				return;
+			}
+		}
+
 		QProcess::startDetached( QStringLiteral("poweroff"), {} );
 	}
 	else
@@ -100,8 +123,6 @@ void LinuxCoreFunctions::powerDown( bool installUpdates )
 		gnomeSessionManager()->asyncCall( QStringLiteral("RequestShutdown") );
 		mateSessionManager()->asyncCall( QStringLiteral("RequestShutdown") );
 		xfcePowerManager()->asyncCall( QStringLiteral("Shutdown") );
-		systemdLoginManager()->asyncCall( QStringLiteral("PowerOff") );
-		consoleKitManager()->asyncCall( QStringLiteral("Stop") );
 	}
 }
 
@@ -351,8 +372,16 @@ LinuxCoreFunctions::DBusInterfacePointer LinuxCoreFunctions::consoleKitManager()
 
 int LinuxCoreFunctions::systemctl( const QStringList& arguments )
 {
-	return QProcess::execute( QStringLiteral("systemctl"),
+	QProcess process;
+	process.start( QStringLiteral("systemctl"),
 							  QStringList( { QStringLiteral("--no-pager"), QStringLiteral("-q") } ) + arguments );
+
+	if( process.waitForFinished() && process.exitStatus() == QProcess::NormalExit )
+	{
+		return process.exitCode();
+	}
+
+	return -1;
 }
 
 
