@@ -1,7 +1,7 @@
 /*
  * LinuxInputDeviceFunctions.cpp - implementation of LinuxInputDeviceFunctions class
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -29,18 +29,6 @@
 #include <X11/XKBlib.h>
 
 
-LinuxInputDeviceFunctions::LinuxInputDeviceFunctions() :
-	m_inputDevicesDisabled( false ),
-	m_origKeyTable( nullptr ),
-	m_keyCodeMin( 0 ),
-	m_keyCodeMax( 0 ),
-	m_keyCodeCount( 0 ),
-	m_keySymsPerKeyCode( 0 )
-{
-}
-
-
-
 void LinuxInputDeviceFunctions::enableInputDevices()
 {
 	if( m_inputDevicesDisabled )
