@@ -1,7 +1,7 @@
 /*
  * LinuxKeyboardInput.h - declaration of LinuxKeyboardInput class
  *
- * Copyright (c) 2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2019-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -26,14 +26,14 @@
 
 #include <QString>
 
-typedef struct FakeKey FakeKey;
-typedef struct _XDisplay Display;
-
 // clazy:excludeall=copyable-polymorphic
 
 class LinuxKeyboardInput
 {
 public:
+	using FakeKey = struct FakeKey;
+	using Display = struct _XDisplay;
+
 	LinuxKeyboardInput();
 	~LinuxKeyboardInput();
 
