@@ -24,6 +24,7 @@
 
 #include <QDBusReply>
 #include <QEventLoop>
+#include <QFileInfo>
 #include <QProcess>
 #include <QTimer>
 
@@ -35,6 +36,7 @@
 #include "LinuxServiceCore.h"
 #include "LinuxSessionFunctions.h"
 #include "ProcessHelper.h"
+#include "VeyonConfiguration.h"
 
 
 LinuxServiceCore::LinuxServiceCore( QObject* parent ) :
@@ -85,6 +87,22 @@ void LinuxServiceCore::startServer( const QString& login1SessionId, const QDBusO
 		return;
 	}
 
+	const auto sessionState = LinuxSessionFunctions::getSessionState( sessionPath );
+	if( sessionState == LinuxSessionFunctions::State::Opening )
+	{
+		vDebug() << "Session" << sessionPath << "still opening - retrying in" << SessionStateProbingInterval << "msecs";
+		QTimer::singleShot( SessionStateProbingInterval, this, [=]() { startServer( login1SessionId, sessionObjectPath ); } );
+		return;
+	}
+
+	// only start server for online or active sessions
+	if( sessionState != LinuxSessionFunctions::State::Online &&
+		sessionState != LinuxSessionFunctions::State::Active )
+	{
+		vDebug() << "Not starting server for session" << sessionPath << "in state" << sessionState;
+		return;
+	}
+
 	const auto sessionLeader = LinuxSessionFunctions::getSessionLeaderPid( sessionPath );
 	if( sessionLeader < 0 )
 	{
@@ -103,7 +121,7 @@ void LinuxServiceCore::startServer( const QString& login1SessionId, const QDBusO
 		return;
 	}
 
-	if( multiSession() == false && m_serverProcesses.isEmpty() == false )
+	if( m_sessionManager.multiSession() == false && m_serverProcesses.isEmpty() == false )
 	{
 		// make sure no other server is still running
 		stopAllServers();
@@ -119,10 +137,18 @@ void LinuxServiceCore::startServer( const QString& login1SessionId, const QDBusO
 	}
 
 	const auto seat = LinuxSessionFunctions::getSessionSeat( sessionPath );
-	const auto sessionId = LinuxSessionFunctions::toSessionId( sessionPath );
+	const auto sessionId = LinuxSessionFunctions::getSessionId( sessionPath );
 
-	vInfo() << "Starting server for new session" << sessionPath
-			<< "with ID" << sessionId
+	// if pam-systemd is not in use, we have to set the XDG_SESSION_ID environment variable manually
+	if( sessionEnvironment.contains( LinuxSessionFunctions::xdgSessionIdEnvVarName() ) == false )
+	{
+		sessionEnvironment.insert( LinuxSessionFunctions::xdgSessionIdEnvVarName(), sessionId );
+	}
+
+	const auto veyonSessionId = m_sessionManager.openSession( sessionId );
+
+	vInfo() << "Starting server for new" << qUtf8Printable(sessionType) << "session" << sessionPath
+			<< "with ID" << veyonSessionId
 			<< "at seat" << seat.path;
 
 	sessionEnvironment.insert( QLatin1String( ServiceDataManager::serviceDataTokenEnvironmentVariable() ),
@@ -130,7 +156,21 @@ void LinuxServiceCore::startServer( const QString& login1SessionId, const QDBusO
 
 	auto process = new QProcess( this );
 	process->setProcessEnvironment( sessionEnvironment );
-	process->start( VeyonCore::filesystem().serverFilePath(), QStringList{} );
+
+	if( VeyonCore::config().logToSystem() )
+	{
+		process->setProcessChannelMode( QProcess::ForwardedChannels );
+	}
+
+	const auto catchsegv{ QStringLiteral("/usr/bin/catchsegv") };
+	if( VeyonCore::isDebugging() && QFileInfo::exists( catchsegv ) )
+	{
+		process->start( catchsegv, { VeyonCore::filesystem().serverFilePath() } );
+	}
+	else
+	{
+		process->start( VeyonCore::filesystem().serverFilePath(), QStringList{} );
+	}
 
 	m_serverProcesses[sessionPath] = process;
 }
@@ -180,6 +220,8 @@ void LinuxServiceCore::connectToLoginManager()
 
 void LinuxServiceCore::stopServer( const QString& sessionPath )
 {
+	m_sessionManager.closeSession( LinuxSessionFunctions::getSessionId( sessionPath ) );
+
 	if( m_serverProcesses.contains( sessionPath ) == false )
 	{
 		return;
