@@ -25,14 +25,14 @@
 #pragma once
 
 #include "LinuxCoreFunctions.h"
-#include "PlatformServiceCore.h"
+#include "PlatformSessionManager.h"
 #include "ServiceDataManager.h"
 
 class QProcess;
 
 // clazy:excludeall=copyable-polymorphic
 
-class LinuxServiceCore : public QObject, PlatformServiceCore
+class LinuxServiceCore : public QObject
 {
 	Q_OBJECT
 public:
@@ -52,6 +52,7 @@ private:
 	static constexpr auto ServerKillTimeout = 10000;
 	static constexpr auto ServerWaitSleepInterval = 100;
 	static constexpr auto SessionEnvironmentProbingInterval = 1000;
+	static constexpr auto SessionStateProbingInterval = 1000;
 	static constexpr auto SessionUptimeSecondsMinimum = 3;
 	static constexpr auto SessionUptimeProbingInterval = 1000;
 
@@ -65,5 +66,6 @@ private:
 	QMap<QString, QProcess *> m_serverProcesses;
 
 	ServiceDataManager m_dataManager{};
+	PlatformSessionManager m_sessionManager{};
 
 };
