@@ -30,8 +30,10 @@
 #include "rfb/keysym.h"
 
 #include "RemoteAccessWidget.h"
-#include "VncView.h"
+#include "VncViewWidget.h"
+#include "VeyonConfiguration.h"
 #include "VeyonConnection.h"
+#include "VeyonMasterInterface.h"
 #include "Computer.h"
 #include "ComputerControlInterface.h"
 #include "PlatformCoreFunctions.h"
@@ -126,8 +128,8 @@ RemoteAccessWidgetToolBar::RemoteAccessWidgetToolBar( RemoteAccessWidget* parent
 	layout->addWidget( m_fullScreenButton );
 	layout->addWidget( m_exitButton );
 	layout->addSpacing( 5 );
-	connect( vncView, &VncView::startConnection, this, &RemoteAccessWidgetToolBar::startConnection );
-	connect( vncView, &VncView::connectionEstablished, this, &RemoteAccessWidgetToolBar::connectionEstablished );
+	connect( vncView, &VncViewWidget::startConnection, this, &RemoteAccessWidgetToolBar::startConnection );
+	connect( vncView, &VncViewWidget::connectionEstablished, this, &RemoteAccessWidgetToolBar::connectionEstablished );
 
 	setFixedHeight( m_exitButton->height() );
 
@@ -136,7 +138,7 @@ RemoteAccessWidgetToolBar::RemoteAccessWidgetToolBar( RemoteAccessWidget* parent
 	m_iconStateTimeLine.setFrameRange( 0, 100 );
 	m_iconStateTimeLine.setDuration( 1500 );
 	m_iconStateTimeLine.setUpdateInterval( 60 );
-	m_iconStateTimeLine.setCurveShape( QTimeLine::SineCurve );
+	m_iconStateTimeLine.easingCurve().setType( QEasingCurve::SineCurve );
 	connect( &m_iconStateTimeLine, &QTimeLine::valueChanged, this, &RemoteAccessWidgetToolBar::updateConnectionAnimation );
 	connect( &m_iconStateTimeLine, &QTimeLine::finished, &m_iconStateTimeLine, &QTimeLine::start );
 }
@@ -269,27 +271,35 @@ RemoteAccessWidget::RemoteAccessWidget( const ComputerControlInterface::Pointer&
 										bool startViewOnly, bool showViewOnlyToggleButton ) :
 	QWidget( nullptr ),
 	m_computerControlInterface( computerControlInterface ),
-	m_vncView( new VncView( computerControlInterface->computer().hostAddress(), -1, this, VncView::RemoteControlMode ) ),
-	m_connection( new VeyonConnection( m_vncView->vncConnection() ) ),
+	m_vncView( new VncViewWidget( computerControlInterface->computer().hostAddress(), -1, this, VncView::RemoteControlMode ) ),
 	m_toolBar( new RemoteAccessWidgetToolBar( this, startViewOnly, showViewOnlyToggleButton ) )
 {
-	setWindowTitle( tr( "%1 - %2 Remote Access" ).arg( computerControlInterface->computer().name(),
-													   VeyonCore::applicationName() ) );
+	const auto openOnMasterScreen = VeyonCore::config().showFeatureWindowsOnSameScreen();
+	const auto master = VeyonCore::instance()->findChild<VeyonMasterInterface *>();
+	if( master && openOnMasterScreen )
+	{
+		const auto masterWindow = master->mainWindow();
+		move( masterWindow->x(), masterWindow->y() );
+	} else {
+		move( 0, 0 );
+	}
+
+	updateRemoteAccessTitle();
+	connect( m_computerControlInterface.data(), &ComputerControlInterface::userChanged, this, &RemoteAccessWidget::updateRemoteAccessTitle );
+
 	setWindowIcon( QPixmap( QStringLiteral(":/remoteaccess/kmag.png") ) );
 	setAttribute( Qt::WA_DeleteOnClose, true );
 
 	m_vncView->move( 0, 0 );
-	connect( m_vncView, &VncView::mouseAtBorder, m_toolBar, &RemoteAccessWidgetToolBar::appear );
-	connect( m_vncView, &VncView::keyEvent, this, &RemoteAccessWidget::checkKeyEvent );
-	connect( m_vncView, &VncView::sizeHintChanged, this, &RemoteAccessWidget::updateSize );
+	m_vncView->installEventFilter( this );
+	connect( m_vncView, &VncViewWidget::mouseAtBorder, m_toolBar, &RemoteAccessWidgetToolBar::appear );
+	connect( m_vncView, &VncViewWidget::sizeHintChanged, this, &RemoteAccessWidget::updateSize );
 
 	showMaximized();
 	VeyonCore::platform().coreFunctions().raiseWindow( this, false );
 
 	showNormal();
 
-	move( 0, 0 );
-
 	toggleViewOnly( startViewOnly );
 }
 
@@ -297,12 +307,31 @@ RemoteAccessWidget::RemoteAccessWidget( const ComputerControlInterface::Pointer&
 
 RemoteAccessWidget::~RemoteAccessWidget()
 {
-	delete m_connection;
 	delete m_vncView;
 }
 
 
 
+bool RemoteAccessWidget::eventFilter( QObject* object, QEvent* event )
+{
+	if( event->type() == QEvent::KeyRelease &&
+		dynamic_cast<QKeyEvent *>( event )->key() == Qt::Key_Escape &&
+		m_vncView->connection()->isConnected() == false )
+	{
+		close();
+		return true;
+	}
+
+	if( object == m_vncView && event->type() == QEvent::FocusOut )
+	{
+		m_toolBar->disappear();
+	}
+
+	return QWidget::eventFilter( object, event );
+}
+
+
+
 void RemoteAccessWidget::enterEvent( QEvent* event )
 {
 	m_toolBar->disappear();
@@ -315,7 +344,7 @@ void RemoteAccessWidget::enterEvent( QEvent* event )
 void RemoteAccessWidget::leaveEvent( QEvent* event )
 {
 	QTimer::singleShot( AppearDelay, this, [this]() {
-		if( underMouse() == false )
+		if( underMouse() == false && window()->isActiveWindow() )
 		{
 			m_toolBar->appear();
 		}
@@ -336,16 +365,6 @@ void RemoteAccessWidget::resizeEvent( QResizeEvent* event )
 
 
 
-void RemoteAccessWidget::checkKeyEvent( unsigned int key, bool pressed )
-{
-	if( pressed && key == XK_Escape && !m_connection->isConnected() )
-	{
-		close();
-	}
-}
-
-
-
 void RemoteAccessWidget::updateSize()
 {
 	if( !( windowState() & Qt::WindowFullScreen ) &&
@@ -384,3 +403,19 @@ void RemoteAccessWidget::takeScreenshot()
 {
 	Screenshot().take( m_computerControlInterface );
 }
+
+
+
+void RemoteAccessWidget::updateRemoteAccessTitle()
+{
+	if ( m_computerControlInterface->userFullName().isEmpty() )
+	{
+		setWindowTitle( tr( "%1 - %2 Remote Access" ).arg( m_computerControlInterface->computer().name(),
+														   VeyonCore::applicationName() ) );
+	} else
+	{
+		setWindowTitle( tr( "%1 - %2 - %3 Remote Access" ).arg( m_computerControlInterface->userFullName(),
+																  m_computerControlInterface->computer().name(),
+																  VeyonCore::applicationName() ) );
+	}
+}
