@@ -43,7 +43,16 @@ ScreenLockFeaturePlugin::ScreenLockFeaturePlugin( QObject* parent ) :
 							 "In this mode all input devices are locked and "
 							 "the screens are blacked." ),
 						 QStringLiteral(":/screenlock/system-lock-screen.png") ),
-	m_features( { m_screenLockFeature } ),
+	m_lockInputDevicesFeature( QStringLiteral( "InputDevicesLock" ),
+							   Feature::Mode | Feature::AllComponents | Feature::Internal,
+							   Feature::Uid( "e4a77879-e544-4fec-bc18-e534f33b934c" ),
+							   {},
+							   tr( "Lock input devices" ), tr( "Unlock input devices" ),
+							   tr( "To reclaim all user's full attention you can lock "
+								   "their computers using this button. "
+								   "In this mode all input devices are locked while the desktop is still visible." ),
+							   QStringLiteral(":/screenlock/system-lock-screen.png") ),
+	m_features( { m_screenLockFeature, m_lockInputDevicesFeature } ),
 	m_lockWidget( nullptr )
 {
 }
@@ -57,44 +66,30 @@ ScreenLockFeaturePlugin::~ScreenLockFeaturePlugin()
 
 
 
-bool ScreenLockFeaturePlugin::startFeature( VeyonMasterInterface& master, const Feature& feature,
-											const ComputerControlInterfaceList& computerControlInterfaces )
+bool ScreenLockFeaturePlugin::controlFeature( Feature::Uid featureUid, Operation operation,
+											 const QVariantMap& arguments,
+											 const ComputerControlInterfaceList& computerControlInterfaces )
 {
-	Q_UNUSED(master);
+	Q_UNUSED(arguments)
 
-	if( feature == m_screenLockFeature )
+	if( hasFeature( featureUid ) == false )
 	{
-		return sendFeatureMessage( FeatureMessage( m_screenLockFeature.uid(), StartLockCommand ),
-								   computerControlInterfaces );
+		return false;
 	}
 
-	return false;
-}
-
-
-
-bool ScreenLockFeaturePlugin::stopFeature( VeyonMasterInterface& master, const Feature& feature,
-										   const ComputerControlInterfaceList& computerControlInterfaces )
-{
-	Q_UNUSED(master);
-
-	if( feature == m_screenLockFeature )
+	if( operation == Operation::Start )
 	{
-		return sendFeatureMessage( FeatureMessage( m_screenLockFeature.uid(), StopLockCommand ),
-								   computerControlInterfaces );
+		sendFeatureMessage( FeatureMessage{ featureUid, StartLockCommand }, computerControlInterfaces );
+
+		return true;
 	}
 
-	return false;
-}
+	if( operation == Operation::Stop )
+	{
+		sendFeatureMessage( FeatureMessage{ featureUid, StopLockCommand }, computerControlInterfaces );
 
-
-
-bool ScreenLockFeaturePlugin::handleFeatureMessage( VeyonMasterInterface& master, const FeatureMessage& message,
-													ComputerControlInterface::Pointer computerControlInterface )
-{
-	Q_UNUSED(master);
-	Q_UNUSED(message);
-	Q_UNUSED(computerControlInterface);
+		return true;
+	}
 
 	return false;
 }
@@ -107,9 +102,10 @@ bool ScreenLockFeaturePlugin::handleFeatureMessage( VeyonServerInterface& server
 {
 	Q_UNUSED(messageContext)
 
-	if( m_screenLockFeature.uid() == message.featureUid() )
+	if( message.featureUid() == m_screenLockFeature.uid() ||
+		message.featureUid() == m_lockInputDevicesFeature.uid() )
 	{
-		if( server.featureWorkerManager().isWorkerRunning( m_screenLockFeature.uid() ) == false &&
+		if( server.featureWorkerManager().isWorkerRunning( message.featureUid() ) == false &&
 			message.command() == StopLockCommand )
 		{
 			return true;
@@ -130,7 +126,8 @@ bool ScreenLockFeaturePlugin::handleFeatureMessage( VeyonWorkerInterface& worker
 {
 	Q_UNUSED(worker);
 
-	if( m_screenLockFeature.uid() == message.featureUid() )
+	if( message.featureUid() == m_screenLockFeature.uid() ||
+		message.featureUid() == m_lockInputDevicesFeature.uid() )
 	{
 		switch( message.command() )
 		{
@@ -139,7 +136,13 @@ bool ScreenLockFeaturePlugin::handleFeatureMessage( VeyonWorkerInterface& worker
 			{
 				VeyonCore::platform().coreFunctions().disableScreenSaver();
 
-				m_lockWidget = new LockWidget( LockWidget::BackgroundPixmap,
+				auto mode = LockWidget::BackgroundPixmap;
+				if( message.featureUid() == m_lockInputDevicesFeature.uid() )
+				{
+					mode = LockWidget::DesktopVisible;
+				}
+
+				m_lockWidget = new LockWidget( mode,
 											   QPixmap( QStringLiteral(":/screenlock/locked-screen-background.png" ) ) );
 			}
 			return true;
