@@ -1,7 +1,7 @@
 /*
  * UserLoginDialog.h - dialog for querying logon credentials
  *
- * Copyright (c) 2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2019-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -40,7 +40,7 @@ public:
 	QString username() const;
 	CryptoCore::PlaintextPassword password() const;
 
-private slots:
+private Q_SLOTS:
 	void updateOkButton();
 
 private:
