@@ -92,6 +92,11 @@ BOOL ultravnc_veyon_load_int( LPCSTR valname, LONG *out )
 		*out = vncServerInstance->configuration().ultraVncDeskDupEngineEnabled() ? 1 : 0;
 		return true;
 	}
+	if( strcmp( valname, "MaxCpu2" ) == 0 )
+	{
+		*out = vncServerInstance->configuration().ultraVncMaxCpu();
+		return true;
+	}
 	if( strcmp( valname, "NewMSLogon" ) == 0 )
 	{
 		*out = 0;
@@ -175,14 +180,14 @@ BuiltinUltraVncServer::~BuiltinUltraVncServer()
 
 
 QWidget* BuiltinUltraVncServer::configurationWidget()
- {
+{
 	return new UltraVncConfigurationWidget( m_configuration );
- }
+}
 
 
 
 void BuiltinUltraVncServer::prepareServer()
- {
+{
 	// initialize global instance handler and main thread ID
 	hAppInstance = GetModuleHandle( nullptr );
 	mainthreadId = GetCurrentThreadId();
@@ -190,12 +195,12 @@ void BuiltinUltraVncServer::prepareServer()
 	hInstResDLL = hAppInstance;
 
 	m_logoffEventFilter = new LogoffEventFilter;
- }
+}
 
 
 
-void BuiltinUltraVncServer::runServer( int serverPort, const Password& password )
- {
+bool BuiltinUltraVncServer::runServer( int serverPort, const Password& password )
+{
 	m_serverPort = serverPort;
 	m_password = password;
 
@@ -232,7 +237,7 @@ void BuiltinUltraVncServer::runServer( int serverPort, const Password& password
 		FreeLibrary( hSHCore );
 	}
 
-	WinVNCAppMain();
+	return WinVNCAppMain() == 1;
 }
 
 
