@@ -73,11 +73,16 @@ public:
 		return Plugin::ProvidesDefaultImplementation;
 	}
 
+	QStringList supportedSessionTypes() const override
+	{
+		return { QStringLiteral("console"), QStringLiteral("rdp") };
+	}
+
 	QWidget* configurationWidget() override;
 
 	void prepareServer() override;
 
-	void runServer( int serverPort, const Password& password ) override;
+	bool runServer( int serverPort, const Password& password ) override;
 
 	int configuredServerPort() override
 	{
