@@ -45,7 +45,7 @@ ComputerControlServer::ComputerControlServer( QObject* parent ) :
 	m_vncServer(),
 	m_vncProxyServer( VeyonCore::config().localConnectOnly() || AccessControlProvider().isAccessToLocalComputerDenied() ?
 						  QHostAddress::LocalHost : QHostAddress::Any,
-					  VeyonCore::config().primaryServicePort() + VeyonCore::sessionId(),
+					  VeyonCore::config().veyonServerPort() + VeyonCore::sessionId(),
 					  this,
 					  this )
 {
@@ -94,7 +94,13 @@ VncProxyConnection* ComputerControlServer::createVncProxyConnection( QTcpSocket*
 																	 const Password& vncServerPassword,
 																	 QObject* parent )
 {
-	return new ComputerControlClient( this, clientSocket, vncServerPort, vncServerPassword, parent );
+	auto client = new ComputerControlClient( this, clientSocket, vncServerPort, vncServerPassword, parent );
+
+	connect( client, &ComputerControlClient::serverConnectionClosed, this,
+		[=]() { checkForIncompleteAuthentication( client->serverClient() ); },
+		Qt::DirectConnection );
+
+	return client;
 }
 
 
@@ -135,6 +141,21 @@ bool ComputerControlServer::sendFeatureMessageReply( const MessageContext& conte
 
 
 
+void ComputerControlServer::checkForIncompleteAuthentication( VncServerClient* client )
+{
+	// connection to client closed during authentication?
+	if( client->protocolState() == VncServerProtocol::AuthenticationTypes ||
+		client->protocolState() == VncServerProtocol::Authenticating )
+	{
+		// then mark as failed authentication and report it
+		client->setAuthState( VncServerClient::AuthState::Failed );
+
+		showAuthenticationMessage( client );
+	}
+}
+
+
+
 void ComputerControlServer::showAuthenticationMessage( VncServerClient* client )
 {
 	if( client->authState() == VncServerClient::AuthState::Failed )
@@ -165,7 +186,8 @@ void ComputerControlServer::showAuthenticationMessage( VncServerClient* client )
 
 void ComputerControlServer::showAccessControlMessage( VncServerClient* client )
 {
-	if( client->accessControlState() == VncServerClient::AccessControlState::Successful )
+	if( client->accessControlState() == VncServerClient::AccessControlState::Successful &&
+		client->protocolState() == VncServerProtocol::State::AccessControl )
 	{
 		vInfo() << "Access control successful for" << client->hostAddress() << client->username();
 
@@ -213,7 +235,7 @@ void ComputerControlServer::updateTrayIconToolTip()
 {
 	auto toolTip = tr( "%1 Service %2 at %3:%4" ).arg( VeyonCore::applicationName(), VeyonCore::version(),
 													   HostAddress::localFQDN(),
-												QString::number( VeyonCore::config().primaryServicePort() + VeyonCore::sessionId() ) );
+												QString::number( VeyonCore::config().veyonServerPort() + VeyonCore::sessionId() ) );
 
 	QStringList clients;
 	for( const auto* client : m_vncProxyServer.clients() )
