@@ -1,7 +1,7 @@
 /*
  * ServerAccessControlManager.h - header file for ServerAccessControlManager
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -42,7 +42,7 @@ public:
 	void removeClient( VncServerClient* client );
 
 
-signals:
+Q_SIGNALS:
 	void finished( VncServerClient* client );
 
 private:
