@@ -28,6 +28,7 @@
 #include "AuthenticationCredentials.h"
 #include "CryptoCore.h"
 #include "VeyonConfiguration.h"
+#include "PlatformSessionFunctions.h"
 #include "PluginManager.h"
 #include "VncServer.h"
 #include "VncServerPluginInterface.h"
@@ -37,6 +38,8 @@ VncServer::VncServer( QObject* parent ) :
 	QThread( parent ),
 	m_pluginInterface( nullptr )
 {
+	const auto currentSessionType = VeyonCore::platform().sessionFunctions().currentSessionType();
+
 	VeyonCore::authenticationCredentials().setInternalVncServerPassword(
 				CryptoCore::generateChallenge().toBase64().left( MAXPWLEN ) );
 
@@ -49,6 +52,14 @@ VncServer::VncServer( QObject* parent ) :
 
 		if( pluginInterface && vncServerPluginInterface )
 		{
+			// skip VNC server plugins which support certain session types only and do not support
+			// the current session type
+			if( vncServerPluginInterface->supportedSessionTypes().isEmpty() == false &&
+				vncServerPluginInterface->supportedSessionTypes().contains( currentSessionType, Qt::CaseInsensitive ) == false )
+			{
+				continue;
+			}
+
 			if( pluginInterface->uid() == VeyonCore::config().vncServerPlugin() )
 			{
 				m_pluginInterface = vncServerPluginInterface;
@@ -134,7 +145,10 @@ void VncServer::run()
 			VeyonCore::authenticationCredentials().setInternalVncServerPassword( m_pluginInterface->configuredPassword() );
 		}
 
-		m_pluginInterface->runServer( serverPort(), password() );
+		if( m_pluginInterface->runServer( serverPort(), password() ) == false )
+		{
+			vCritical() << "An error occurred while running the VNC server plugin";
+		}
 
 		vDebug() << "finished";
 	}
