@@ -1,7 +1,7 @@
 /*
  * FeatureWorkerManagerConnection.cpp - class which handles communication between service and feature
  *
- * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -40,6 +40,8 @@ FeatureWorkerManagerConnection::FeatureWorkerManagerConnection( VeyonWorkerInter
 	m_socket( this ),
 	m_featureUid( featureUid )
 {
+	connect( &m_connectTimer, &QTimer::timeout, this, &FeatureWorkerManagerConnection::tryConnection );
+
 	connect( &m_socket, &QTcpSocket::connected,
 			 this, &FeatureWorkerManagerConnection::sendInitMessage );
 
@@ -49,8 +51,7 @@ FeatureWorkerManagerConnection::FeatureWorkerManagerConnection( VeyonWorkerInter
 	connect( &m_socket, &QTcpSocket::readyRead,
 			 this, &FeatureWorkerManagerConnection::receiveMessage );
 
-	m_socket.connectToHost( QHostAddress::LocalHost,
-							static_cast<quint16>( VeyonCore::config().featureWorkerManagerPort() + VeyonCore::sessionId() ) );
+	tryConnection();
 }
 
 
@@ -62,10 +63,27 @@ bool FeatureWorkerManagerConnection::sendMessage( const FeatureMessage& message
 
 
 
+void FeatureWorkerManagerConnection::tryConnection()
+{
+	if( m_socket.state() != QTcpSocket::ConnectedState )
+	{
+		const auto port = quint16( VeyonCore::config().featureWorkerManagerPort() + VeyonCore::sessionId() );
+
+		vDebug() << "connecting to FeatureWorkerManager at port" << port;
+
+		m_socket.connectToHost( QHostAddress::LocalHost, port );
+		m_connectTimer.start( ConnectTimeout );
+	}
+}
+
+
+
 void FeatureWorkerManagerConnection::sendInitMessage()
 {
 	vDebug() << m_featureUid;
 
+	m_connectTimer.stop();
+
 	FeatureMessage( m_featureUid, FeatureMessage::InitCommand ).send( &m_socket );
 }
 
